@@ -5,8 +5,8 @@ from vflow.convert import to_tuple, to_list
 class TestBasic():
     def setup(self):
         self.pipeline = vflow.PCSPipeline()
-        self.module_set = vflow.ModuleSet(name='s', modules={})
-        self.module = vflow.Module()
+        self.module_set = vflow.Vset(name='s', modules={})
+        self.module = vflow.Vfunc()
 
     def test_class_initializations(self):
         assert self.pipeline.steps is not None
